/*
 *******************************************************************
 *              TMark favorites plugin for TVBrowser               *
 *                                                                 *
 * Copyright (C) 2006 Tomas Schackert.                             *
 * Contact koumori@web.de                                          *
 *******************************************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, in version 2 of the License.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program, in a file called LICENSE in the top
 directory of the distribution; if not, write to 
 the Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA  02111-1307  USA
 
 *******************************************************************/

package tmarkplugin.properties;

import java.util.Calendar;
import java.util.Date;

/**
 * @author Tomas
 *
 */
public class CalendarProperty extends Property {
	private String key;
	private long value;
	private long defaultvalue;
	private boolean loaded=false;
	
	public CalendarProperty(PropertySource props,CalendarProperty src) {
		super(props);
		set(src);
	}
	/**
	 * @param props
	 */
	public CalendarProperty(PropertySource props,String key,Calendar defaultvalue) {
		super(props);
		this.key=key;
		this.value=0;
		this.loaded=false;
		this.defaultvalue=defaultvalue.getTimeInMillis();
	}
	public CalendarProperty(Calendar value,Calendar defaultvalue) {
		super(null);
		this.key=null;
		this.value=value.getTimeInMillis();
		this.loaded=true;
		this.defaultvalue=defaultvalue.getTimeInMillis();
	}

	/**
	 * @see tmarkplugin.properties.Property#reset()
	 */
	public void reset() {
		this.setLongProperty(key,this.value=defaultvalue);
		loaded=true;
		fireChanged();
	}
	private void load(){
		value=getLongProperty(key,defaultvalue);
		loaded=true;
	}
	public Calendar get(){
		if (!loaded) load();
		Calendar result=Calendar.getInstance();
		result.setTimeInMillis(value);
		return result;
	}
	public void set(Calendar c){
		this.setLongProperty(key,this.value=c.getTimeInMillis());
		loaded=true;
		fireChanged();
	}
	public void set(Date d){
		this.setLongProperty(key,this.value=d.getTime());
		loaded=true;
		fireChanged();
	}
	public void set(CalendarProperty src){
		if (!src.loaded)src.load();
		this.key=src.key;
		this.defaultvalue=src.defaultvalue;
		this.setLongProperty(key,this.value=src.value);
		loaded=true;
		fireChanged();
	}
}
